Enum shades::Swizzle [−][src]
Swizzle channel selector.
This type gives the dimension of the target expression (output) and dimension of the source expression (input). The
SwizzleSelector also to select a specific channel in the input expression.
Variants
D1(SwizzleSelector)Create a one-channel expression.
Create a two-channel expression.
Create a three-channel expression.
Create a four-channel expression.